@@ -87,7 +87,7 @@ class CLIParser:
             type=str,
             required=False,
             action="append",
-            help="user-defined Mustache variable substitution; can be supplied multiple times",
+            help="user-defined variable substitutions; can be supplied multiple times",
             metavar="<var1=v1>",
         )
         parser.add_argument(
@@ -301,7 +301,7 @@ class CLIParser:
                 "--directory",
                 "-d",
                 type=str,
-                required=True,
+                required=False,
                 help="the Object Store directory name to use when uploading objects",
                 metavar="<directory>",
             )
@@ -448,10 +448,6 @@ class CLIParser:
     def abort(self) -> Optional[bool]:
         return self.args.abort
 
-    @property
-    def no_mustache(self) -> Optional[bool]:
-        return self.args.no_mustache
-
     @property
     def interactive(self) -> Optional[bool]:
         return self.args.interactive
@@ -497,8 +493,8 @@ class CLIParser:
         return self.args.debug
 
     @property
-    def directory(self) -> Optional[str]:
-        return self.args.directory
+    def directory(self) -> str:
+        return "" if self.args.directory is None else self.args.directory
 
     @property
     def files(self) -> List[str]:
